EMMO-python documentation
=========================
See the root [README.md](../README.md) file for a short overview of
EMMO-python.



Building a EMMO docker image
----------------------------
See the [docker instructions](docker-instructions.md).
